@@ -38,9 +38,12 @@ void LsText::applySettings()
 }
 
 void LsText::paint(QPainter *painter, const QStyleOptionGraphicsItem* option, QWidget *)
-{
+{    
     painter->setClipRect(option->exposedRect);
-    painter->setFont(m_Font);
-    painter->setPen(m_Color);
-    painter->drawText(boundingRect(), m_Alignment | Qt::TextSingleLine, m_Text);
+
+    if (!m_Text.isEmpty()){
+        painter->setFont(m_Font);
+        painter->setPen(m_Color);
+        painter->drawText(boundingRect(), m_Alignment | Qt::TextSingleLine, m_Text);
+    }
 }
