@@ -24,9 +24,6 @@ LsWifi::LsWifi(QString name) :
     m_Connected = false;
     applySettings();
 #ifdef Q_WS_MAEMO_5
-    QDBusConnection::systemBus().connect("com.nokia.icd", "/com/nokia/icd", "com.nokia.icd",
-                                         "status_changed", this, SLOT(netStateChanged(QString,QString,QString,QString)));
-
     if (LockScreen::Debug){
         m_Image = QPixmap(m_Wifi);
         m_Connected = true;
@@ -74,3 +71,40 @@ void LsWifi::netStateChanged(QString, QString type, QString state, QString)
         update();
     }
 }
+
+void LsWifi::startUpdate()
+{
+#ifdef Q_WS_MAEMO_5
+    if (!LockScreen::Debug)
+        getNetworkState();
+    QDBusConnection::systemBus().connect("com.nokia.icd", "/com/nokia/icd", "com.nokia.icd",
+                                         "status_changed", this, SLOT(netStateChanged(QString,QString,QString,QString)));
+#endif
+}
+
+void LsWifi::stopUpdate()
+{
+#ifdef Q_WS_MAEMO_5
+    QDBusConnection::systemBus().disconnect("com.nokia.icd", "/com/nokia/icd", "com.nokia.icd",
+                                            "status_changed", this, SLOT(netStateChanged(QString,QString,QString,QString)));
+#endif
+}
+
+void LsWifi::getNetworkState()
+{
+    QProcess p;
+    p.start("sh -c \"/sbin/route | awk '/default/ {print $NF}'\"");
+    p.waitForFinished(-1);
+
+    QString res = p.readAll().trimmed();
+    qDebug() << "Network state:" << res;
+
+    if (res == "wlan0")
+        m_Image = QPixmap(m_Wifi);
+    else if (res == "gprs0")
+        m_Image = QPixmap(m_Gprs);
+    else
+        m_Image = QPixmap();
+    update();
+}
+
